from django.core.management.base import BaseCommand
from django.core import management
from django.core import serializers
from django.conf import settings
from goscale.themes import models, site_middleware
from cms.models import Page
from filer.models import Image, File, Folder
from goscale.models import Post


class Dump(BaseCommand):
    help = "Dumps DB and pages separately for each site."

    def handle(self, *args, **options):
        dump_format = 'json' #'json-pretty'
        # delete posts
        Post.objects.all().delete()

        # serialize pages for themes
        for theme in models.Theme.objects.all():
            site = theme.sites.all()[0]
            pages = Page.objects.filter(site=site)
            file = '%s/fixtures/pages_%s.json' % (settings.PROJECT_PATH, theme.name)
            with open(file, 'w+') as f:
                f.write(serializers.serialize(dump_format, pages, indent=4, use_natural_keys=True))
            print 'Saved %s' % file


        # serialize the rest
        file = '%s/fixtures/%s.json' % (settings.PROJECT_PATH, 'themes')
        with open(file, 'w+') as f:
            management.call_command('dumpdata', 'themes', indent=4, use_natural_keys=True, stdout=f, format=dump_format)
        print 'Saved %s' % file

        file = '%s/fixtures/%s.json' % (settings.PROJECT_PATH, 'sites')
        with open(file, 'w+') as f:
            management.call_command('dumpdata', 'sites', indent=4, use_natural_keys=True, stdout=f, format=dump_format)
        print 'Saved %s' % file

        file = '%s/fixtures/%s.json' % (settings.PROJECT_PATH, 'auth')
        with open(file, 'w+') as f:
            management.call_command('dumpdata', 'auth', indent=4, exclude=['auth.Permission'],
                                    use_natural_keys=True, stdout=f, format=dump_format)
        print 'Saved %s' % file

        file = '%s/fixtures/%s.json' % (settings.PROJECT_PATH, 'placeholders')
        with open(file, 'w+') as f:
            management.call_command('dumpdata', 'cms.Placeholder', indent=4, use_natural_keys=True, stdout=f,
                                    format=dump_format)
        print 'Saved %s' % file

        file = '%s/fixtures/%s.json' % (settings.PROJECT_PATH, 'rest')
        with open(file, 'w+') as f:
            management.call_command('dumpdata', indent=4, use_natural_keys=True, use_base_manager=True, exclude=[
                'contenttypes',
                'cms.Placeholder',
                'cms.Page',
                'goscale.Post',
                'auth.Permission',
                'admin',
                'sites',
                'themes',
                ], stdout=f, format=dump_format)
        print 'Saved %s' % file


from django.core.management.base import BaseCommand
from django.core import management
from django.conf import settings
from goscale.themes import models, site_middleware, set_themes
from cms.models import Page
from django.core.serializers import json, python


class Load(BaseCommand):
    help = "Restores DB and pages separately for each site."

    def handle(self, *args, **options):
        # restore sites and themes
        file = '%s/fixtures/%s.json' % (settings.PROJECT_PATH, 'sites')
        management.call_command('loaddata', file)
        print 'Restored %s' % file
        file = '%s/fixtures/%s.json' % (settings.PROJECT_PATH, 'themes')
        management.call_command('loaddata', file)
        print 'Restored %s' % file

        # restore users
        file = '%s/fixtures/%s.json' % (settings.PROJECT_PATH, 'auth')
        management.call_command('loaddata', file)
        print 'Restored %s' % file

        # restore placeholders
        file = '%s/fixtures/%s.json' % (settings.PROJECT_PATH, 'placeholders')
        management.call_command('loaddata', file)
        print 'Restored %s' % file
#
#        # restore pages
        for theme in models.Theme.objects.all():
            site = theme.sites.all()[0]
            # set theme
            site_middleware.SITE_ID.value = site.id
            set_themes()

            # load pages
            file = '%s/fixtures/pages_%s.json' % (settings.PROJECT_PATH, theme.name)
            management.call_command('loaddata', file)
            print 'Restored %s' % file

        # restore the rest
        file = '%s/fixtures/%s.json' % (settings.PROJECT_PATH, 'rest')
        management.call_command('loaddata', file)
        print 'Restored %s' % file


from django.core.management.base import BaseCommand
from django.conf import settings
from goscale.themes import set_themes


class Debug(BaseCommand):
    help = "Debug command for devs."

    def handle(self, *args, **options):
        set_themes()
        print 'TEMPLATE_DIRS: %s' % settings.TEMPLATE_DIRS



# -*- coding: utf-8 -*-
import simplejson
from django.conf import settings
from django.contrib.sites.models import get_current_site
from goscale import conf


def theme(request):
    # set  config
    site_theme = settings.THEME
    static_theme_url = '%sthemes/%s/static/' % (settings.STATIC_URL, site_theme)
    static_common_url = '%sthemes/common/static/' % settings.STATIC_URL
    config = {}
    settings_list = ['GOSCALE_BOOTSTRAP_THEMES', 'GOSCALE_BOOTSTRAP_THEME',
                     'GOSCALE_AJAXLINKS', 'GOSCALE_AJAXLINKS_EXCEPTIONS']
    for setting in settings_list:
        config[setting] = conf.__dict__.get(setting)
    theme = request.GET.get('theme')
    # build the context
    return {
        'site': get_current_site(request),
        'GOSCALE_THEME': site_theme,
        'STATIC_THEME_URL': static_theme_url,
        'STATIC_COMMON_URL': static_common_url,
        'goscale_config': config,
        'goscale_bootstrap_theme': theme if theme else conf.GOSCALE_BOOTSTRAP_THEME,
        'goscale_config_json': simplejson.dumps(config),
    }



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Vimeo'
        db.create_table('cmsplugin_vimeo', (
            ('cmsplugin_ptr', self.gf('django.db.models.fields.related.OneToOneField')(to=orm['cms.CMSPlugin'], unique=True, primary_key=True)),
            ('template', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
            ('updated', self.gf('django.db.models.fields.DateTimeField')(db_index=True, null=True, blank=True)),
            ('playlist', self.gf('django.db.models.fields.CharField')(max_length=250)),
            ('lightbox', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('user', self.gf('django.db.models.fields.CharField')(max_length=250, null=True, blank=True)),
        ))
        db.send_create_signal('videos', ['Vimeo'])

        # Adding M2M table for field posts on 'Vimeo'
        db.create_table('videos_vimeo_posts', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('vimeo', models.ForeignKey(orm['videos.vimeo'], null=False)),
            ('post', models.ForeignKey(orm['goscale.post'], null=False))
        ))
        db.create_unique('videos_vimeo_posts', ['vimeo_id', 'post_id'])

        # Adding model 'Youtube'
        db.create_table('cmsplugin_youtube', (
            ('cmsplugin_ptr', self.gf('django.db.models.fields.related.OneToOneField')(to=orm['cms.CMSPlugin'], unique=True, primary_key=True)),
            ('template', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
            ('updated', self.gf('django.db.models.fields.DateTimeField')(db_index=True, null=True, blank=True)),
            ('playlist', self.gf('django.db.models.fields.CharField')(max_length=250)),
            ('lightbox', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('channel', self.gf('django.db.models.fields.CharField')(max_length=250, null=True, blank=True)),
        ))
        db.send_create_signal('videos', ['Youtube'])

        # Adding M2M table for field posts on 'Youtube'
        db.create_table('videos_youtube_posts', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('youtube', models.ForeignKey(orm['videos.youtube'], null=False)),
            ('post', models.ForeignKey(orm['goscale.post'], null=False))
        ))
        db.create_unique('videos_youtube_posts', ['youtube_id', 'post_id'])


    def backwards(self, orm):
        # Deleting model 'Vimeo'
        db.delete_table('cmsplugin_vimeo')

        # Removing M2M table for field posts on 'Vimeo'
        db.delete_table('videos_vimeo_posts')

        # Deleting model 'Youtube'
        db.delete_table('cmsplugin_youtube')

        # Removing M2M table for field posts on 'Youtube'
        db.delete_table('videos_youtube_posts')


    models = {
        'cms.cmsplugin': {
            'Meta': {'object_name': 'CMSPlugin'},
            'changed_date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime(2013, 1, 28, 0, 0)'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'language': ('django.db.models.fields.CharField', [], {'max_length': '15', 'db_index': 'True'}),
            'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cms.CMSPlugin']", 'null': 'True', 'blank': 'True'}),
            'placeholder': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cms.Placeholder']", 'null': 'True'}),
            'plugin_type': ('django.db.models.fields.CharField', [], {'max_length': '50', 'db_index': 'True'}),
            'position': ('django.db.models.fields.PositiveSmallIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        },
        'cms.placeholder': {
            'Meta': {'object_name': 'Placeholder'},
            'default_width': ('django.db.models.fields.PositiveSmallIntegerField', [], {'null': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'slot': ('django.db.models.fields.CharField', [], {'max_length': '50', 'db_index': 'True'})
        },
        'goscale.post': {
            'Meta': {'object_name': 'Post'},
            'attributes': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'author': ('django.db.models.fields.CharField', [], {'max_length': '250', 'null': 'True', 'blank': 'True'}),
            'categories': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '250', 'null': 'True', 'blank': 'True'}),
            'content_type': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '250', 'null': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'link': ('django.db.models.fields.URLField', [], {'db_index': 'True', 'max_length': '200', 'null': 'True', 'blank': 'True'}),
            'permalink': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '250', 'null': 'True', 'blank': 'True'}),
            'published': ('django.db.models.fields.DateTimeField', [], {'db_index': 'True', 'null': 'True', 'blank': 'True'}),
            'slug': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '250', 'null': 'True', 'blank': 'True'}),
            'summary': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '250', 'null': 'True', 'blank': 'True'}),
            'updated': ('django.db.models.fields.DateTimeField', [], {'db_index': 'True', 'null': 'True', 'blank': 'True'})
        },
        'videos.vimeo': {
            'Meta': {'object_name': 'Vimeo', 'db_table': "'cmsplugin_vimeo'"},
            'cmsplugin_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['cms.CMSPlugin']", 'unique': 'True', 'primary_key': 'True'}),
            'lightbox': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'playlist': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'posts': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['goscale.Post']", 'symmetrical': 'False'}),
            'template': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'updated': ('django.db.models.fields.DateTimeField', [], {'db_index': 'True', 'null': 'True', 'blank': 'True'}),
            'user': ('django.db.models.fields.CharField', [], {'max_length': '250', 'null': 'True', 'blank': 'True'})
        },
        'videos.youku': {
            'Meta': {'object_name': 'YouKu', 'db_table': "'cmsplugin_youku'"},
            'cmsplugin_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['cms.CMSPlugin']", 'unique': 'True', 'primary_key': 'True'}),
            'lightbox': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'playlist': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'posts': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['goscale.Post']", 'symmetrical': 'False'}),
            'template': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'updated': ('django.db.models.fields.DateTimeField', [], {'db_index': 'True', 'null': 'True', 'blank': 'True'})
        },
        'videos.youtube': {
            'Meta': {'object_name': 'Youtube', 'db_table': "'cmsplugin_youtube'"},
            'channel': ('django.db.models.fields.CharField', [], {'max_length': '250', 'null': 'True', 'blank': 'True'}),
            'cmsplugin_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['cms.CMSPlugin']", 'unique': 'True', 'primary_key': 'True'}),
            'lightbox': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'playlist': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'posts': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['goscale.Post']", 'symmetrical': 'False'}),
            'template': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'updated': ('django.db.models.fields.DateTimeField', [], {'db_index': 'True', 'null': 'True', 'blank': 'True'})
        }
    }

    complete_apps = ['videos']